import React from "react";
import { BrowserRouter, Routes, Route } from "react-router-dom";
import { connect } from "react-redux";
import { developer } from "./redux/actions";

//components
import Home from "./views/Home";
import FeaturesPage from "./views/FeaturesPage";
import Dialog from "./components/Dialog";
import Navbar from "./components/Navbar";

export const Router = ({
  isDark,
  headerOptions,
  dialog,
  menu,
  setMenu,
  setDevice,
  device,
}) => {
  const prevDefault = React.useCallback(
    (e) => {
      setMenu();
      e.stopPropagation();
    },
    [setMenu]
  );

  React.useEffect(() => {
    //initial device property
    const width = window.innerWidth;
    if (width <= 640) {
      setDevice("mobile");
    } else if (width > 640 && width <= 1007) {
      setDevice("tablet");
    } else {
      setDevice("desktop");
    }
  }, []);

  React.useEffect(() => {
    window.addEventListener("resize", () => {
      const width = window.innerWidth;
      if (width <= 640) {
        if (device === "mobile") {
          return;
        } else {
          setDevice("mobile");
        }
      } else if (width > 640 && width < 1007) {
        if (device === "tablet") {
          return;
        } else {
          setDevice("tablet");
        }
      } else if (width > 1007) {
        if (device === "desktop") {
          return;
        } else {
          setDevice("desktop");
        }
      }
    });
  }, [device]);

  return (
    <div className={`${isDark ? "dark" : ""}`}>
      <div
        className={`min-h-screen min-w-screen rtl overflow-x-hidden lg:py-0 ${
          isDark ? "dark:bg-grayDarkJungle" : "bg-white"
        }`}
      >
        {menu && (
          <div
            className="h-screen w-screen fixed top-0 left-0 bg-black bg-opacity-50 backdrop-filter backdrop-blur-md"
            onClick={(e) => prevDefault(e)}
            style={{ zIndex: 60 }}
          ></div>
        )}
        {dialog.open && <Dialog />}
        <BrowserRouter>
          {headerOptions?.shown && <Navbar headerOptions={headerOptions} />}
          <Routes>
            <Route path="/" exact element={<Home />} />
            <Route path="/features" exact element={<FeaturesPage />} />
            <Route path="*" exact element={<div>hichi nist :</div>} />
          </Routes>
        </BrowserRouter>
      </div>
    </div>
  );
};

const mapStateToProps = (state) => ({
  isDark: state.developer.isDark,
  isLogin: state.user.status,
  headerOptions: state.developer.headerOptions,
  dialog: state.developer.dialog,
  menu: state.developer.menu,
  device: state.developer.device,
});

const mapDispatchToProps = {
  setMenu: developer.setMenu,
  setDevice: developer.setDevice,
};

export default connect(mapStateToProps, mapDispatchToProps)(Router);
