import React from "react";
import { connect } from "react-redux";
import { Carousel } from "@trendyol-js/react-carousel";

//components
import Button from "../../../../components/Button";

//assets
import grandFatherImage from "./assets/grandFather.svg";
import pic1Image from "./assets/pic1.svg";
import pic2Image from "./assets/pic2.svg";
import pic3Image from "./assets/pic3.svg";
import nextIcon from "../../../../assets/icons/next.svg";

export const Samples = ({ uselessProps }) => {
  const [activeProject, setActiveProject] = React.useState(null);
  const [itemsToShow, setItemsToShow] = React.useState(4);

  const Info = () => {
    return (
      <div
        className="flex justify-between border border-solid border-primary-5 rounded-lg px-7 py-16 mt-10"
        style={{
          width : `calc(100% - (100vw / 12 * 10 / ${itemsToShow * 10} * 2))`
        }}
      >
        <div className="flex flex-col flex-1">
          <strong className="text-primary-4 font-4 text-2x">
            آقا بزرگ
            <br /> یک متن توضیح کوتاه در این قسمت قرار می‌گیرد
          </strong>
          <p className="text-2x font-3 text-primary-2 mt-3">
            فرق نمی‌کند کاربران شما با تلفن‌های همراه یا کامپیوترهای شخصی خود
            وارد حسابشان شوند، دسترسی از هر مکان و زمانی امکان پذیر است
          </p>
        </div>
        <div className="flex flex-col flex-1 justify-center items-end">
          <Button
            title="مشاهده و کار با پروژه"
            round="rounded-full"
            borderColor="text-primary-5"
            color="text-primary-4"
            padding="px-10 py-5"
            backgroundColor="bg-green-50 bg-opacity-50"
          />
        </div>
      </div>
    );
  };

  const items = React.useMemo(() => {
    return [
      {
        id: 0,
        title: "آقا بزرگ",
        image: grandFatherImage,
      },
      {
        id: 1,
        title: "ایما",
        image: pic1Image,
      },
      {
        id: 2,
        title: "شهرخوبان",
        image: pic2Image,
      },
      {
        id: 3,
        title: "رمضان",
        image: pic3Image,
      },
      {
        id: 4,
        title: "ایما",
        image: pic1Image,
      },
      {
        id: 5,
        title: "شهرخوبان",
        image: pic2Image,
      },
      {
        id: 5,
        title: "رمضان",
        image: pic3Image,
      },
    ];
  }, [uselessProps]);

  const renderArrow = React.useCallback(
    ({ type, onClick, isEdge }) => {
      console.log(type);
      // const pointer = type === consts.PREV ? "👈" : "👉";
      return (
        <button onClick={onClick} disabled={isEdge}>
          arrow
        </button>
      );
    },
    [uselessProps]
  );

  return (
    <div className="w-10/12 h-screen flex flex-col justify-around items-center py-5 relative">
      <div className="flex flex-col mb-32">
        <strong className="text-primary-3 font-6 text-5x">
          با افتخار قدرت گرفته از داستان بازی{" "}
        </strong>
        <p className="text-2x font-4 text-gray-400 mt-3">
          در این قسمت یک متن بسیار عجیب و جالب باید قرار بگیرید
        </p>
      </div>
      <div className="relative w-full" style={{ direction: "ltr" }}>
        <Carousel
          className="flex"
          show={itemsToShow}
          useArrowKeys={true}
          swiping={true}
          rightArrow={
            <img
              className="absolute top-1/2 transform -translate-y-1/2 cursor-pointer p-0"
              src={nextIcon}
              alt=""
              // onClick={(e) => e.stopPropagation()}
            />
          }
          leftArrow={
            <img
              className="absolute top-1/2 transform -translate-y-1/2  -translate-x-16 cursor-pointer rotate-180 p-2 -left-3"
              src={nextIcon}
              alt=""
              // onClick={(e) => e.stopPropagation()}
            />
          }
        >
          {items.map((item, index) => (
            <article
              className="flex flex-col gap-4"
              key={index}
              style={{
                direction: "rtl",
                padding: `16px calc(100vw / 12 * 10 / ${itemsToShow * 10})`,
              }}
            >
              <img
                src={item.image}
                alt={item.title}
                className={`rounded-lg ${
                  activeProject === index
                    ? "border border-solid border-primary-4"
                    : "shadow-lg"
                }`}
                style={{
                  width: `calc(100vw / 10 * 12 / ${itemsToShow})`,
                }}
                onDragStart={(e) => e.preventDefault()}
              />
              <strong className="text-1x text-primary-4 font-4">
                {item.title}
              </strong>
            </article>
          ))}
        </Carousel>
      </div>
      <Info />
    </div>
  );
};

const mapStateToProps = (state) => ({});

const mapDispatchToProps = {};

export default connect(mapStateToProps, mapDispatchToProps)(Samples);
